==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/SAMLPayLoadDataAssertionClaimsValue.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner;
import com.okta.sdk.resource.model.SAMLPayLoadDataAssertionClaimsValueAttributes;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * SAMLPayLoadDataAssertionClaimsValue
 */
@JsonPropertyOrder({ SAMLPayLoadDataAssertionClaimsValue.JSON_PROPERTY_ATTRIBUTES,
        SAMLPayLoadDataAssertionClaimsValue.JSON_PROPERTY_ATTRIBUTE_VALUES })
@JsonTypeName("SAMLPayLoad_data_assertion_claims_value")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class SAMLPayLoadDataAssertionClaimsValue implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ATTRIBUTES = "attributes";
    private SAMLPayLoadDataAssertionClaimsValueAttributes attributes;

    public static final String JSON_PROPERTY_ATTRIBUTE_VALUES = "attributeValues";
    private List<SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner> attributeValues = null;

    public SAMLPayLoadDataAssertionClaimsValue() {
    }

    public SAMLPayLoadDataAssertionClaimsValue attributes(SAMLPayLoadDataAssertionClaimsValueAttributes attributes) {

        this.attributes = attributes;
        return this;
    }

    /**
     * Get attributes
     *
     * @return attributes
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ATTRIBUTES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public SAMLPayLoadDataAssertionClaimsValueAttributes getAttributes() {
        return attributes;
    }

    @JsonProperty(JSON_PROPERTY_ATTRIBUTES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAttributes(SAMLPayLoadDataAssertionClaimsValueAttributes attributes) {
        this.attributes = attributes;
    }

    public SAMLPayLoadDataAssertionClaimsValue attributeValues(
            List<SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner> attributeValues) {

        this.attributeValues = attributeValues;
        return this;
    }

    public SAMLPayLoadDataAssertionClaimsValue addattributeValuesItem(
            SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner attributeValuesItem) {
        if (this.attributeValues == null) {
            this.attributeValues = new ArrayList<>();
        }
        this.attributeValues.add(attributeValuesItem);
        return this;
    }

    /**
     * Get attributeValues
     *
     * @return attributeValues
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ATTRIBUTE_VALUES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner> getAttributeValues() {
        return attributeValues;
    }

    @JsonProperty(JSON_PROPERTY_ATTRIBUTE_VALUES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAttributeValues(List<SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner> attributeValues) {
        this.attributeValues = attributeValues;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SAMLPayLoadDataAssertionClaimsValue saMLPayLoadDataAssertionClaimsValue = (SAMLPayLoadDataAssertionClaimsValue) o;
        return Objects.equals(this.attributes, saMLPayLoadDataAssertionClaimsValue.attributes)
                && Objects.equals(this.attributeValues, saMLPayLoadDataAssertionClaimsValue.attributeValues);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(attributes, attributeValues);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SAMLPayLoadDataAssertionClaimsValue {\n");
        sb.append("    attributes: ").append(toIndentedString(attributes)).append("\n");
        sb.append("    attributeValues: ").append(toIndentedString(attributeValues)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/SAMLPayLoadDataAssertionClaimsValue.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner;
import com.okta.sdk.resource.model.SAMLPayLoadDataAssertionClaimsValueAttributes;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * SAMLPayLoadDataAssertionClaimsValue
 */
@JsonPropertyOrder({ SAMLPayLoadDataAssertionClaimsValue.JSON_PROPERTY_ATTRIBUTES,
        SAMLPayLoadDataAssertionClaimsValue.JSON_PROPERTY_ATTRIBUTE_VALUES })
@JsonTypeName("SAMLPayLoad_data_assertion_claims_value")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class SAMLPayLoadDataAssertionClaimsValue implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ATTRIBUTES = "attributes";
    private SAMLPayLoadDataAssertionClaimsValueAttributes attributes;

    public static final String JSON_PROPERTY_ATTRIBUTE_VALUES = "attributeValues";
    private List<SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner> attributeValues = null;

    public SAMLPayLoadDataAssertionClaimsValue() {
    }

    public SAMLPayLoadDataAssertionClaimsValue attributes(SAMLPayLoadDataAssertionClaimsValueAttributes attributes) {

        this.attributes = attributes;
        return this;
    }

    /**
     * Get attributes
     *
     * @return attributes
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ATTRIBUTES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public SAMLPayLoadDataAssertionClaimsValueAttributes getAttributes() {
        return attributes;
    }

    @JsonProperty(JSON_PROPERTY_ATTRIBUTES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAttributes(SAMLPayLoadDataAssertionClaimsValueAttributes attributes) {
        this.attributes = attributes;
    }

    public SAMLPayLoadDataAssertionClaimsValue attributeValues(
            List<SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner> attributeValues) {

        this.attributeValues = attributeValues;
        return this;
    }

    public SAMLPayLoadDataAssertionClaimsValue addattributeValuesItem(
            SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner attributeValuesItem) {
        if (this.attributeValues == null) {
            this.attributeValues = new ArrayList<>();
        }
        this.attributeValues.add(attributeValuesItem);
        return this;
    }

    /**
     * Get attributeValues
     *
     * @return attributeValues
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ATTRIBUTE_VALUES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner> getAttributeValues() {
        return attributeValues;
    }

    @JsonProperty(JSON_PROPERTY_ATTRIBUTE_VALUES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAttributeValues(List<SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner> attributeValues) {
        this.attributeValues = attributeValues;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SAMLPayLoadDataAssertionClaimsValue saMLPayLoadDataAssertionClaimsValue = (SAMLPayLoadDataAssertionClaimsValue) o;
        return Objects.equals(this.attributes, saMLPayLoadDataAssertionClaimsValue.attributes)
                && Objects.equals(this.attributeValues, saMLPayLoadDataAssertionClaimsValue.attributeValues);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(attributes, attributeValues);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SAMLPayLoadDataAssertionClaimsValue {\n");
        sb.append("    attributes: ").append(toIndentedString(attributes)).append("\n");
        sb.append("    attributeValues: ").append(toIndentedString(attributeValues)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
